Name:           jsoup
Summary:        Java library for working with real-world HTML
Version:        1.13.1
Release:        %mkrel 1
Group:          Development/Java
License:        MIT

URL:            http://jsoup.org/

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# The sources contain non-free scraped web pages as test data
Source1:        generate-tarball.sh

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)

%description
jsoup is a Java library for working with real-world HTML.
It provides a very convenient API for extracting and manipulating data,
using the best of DOM, CSS, and jquery-like methods.

jsoup implements the WHATWG HTML5 specification,
and parses HTML to the same DOM as modern browsers do.

 - scrape and parse HTML from a URL, file, or string
 - find and extract data, using DOM traversal or CSS selectors
 - manipulate the HTML elements, attributes, and text
 - clean user-submitted content against a safe white-list,
   to prevent XSS attacks
 - output tidy HTML

jsoup is designed to deal with all varieties of HTML found in the wild;
from pristine and validating, to invalid tag-soup;
jsoup will create a sensible parse tree.


%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :maven-failsafe-plugin
%pom_remove_plugin :maven-javadoc-plugin

# Expose internal packages in the OSGi metadata, clearly marking them as such
# using the x-internal attribute
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" \
  "<_exportcontents>*.internal;x-internal:=true,*</_exportcontents>"

%build
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%doc README.md CHANGES
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE




%changelog
* Fri Sep 04 2020 daviddavid <daviddavid> 1.13.1-1.mga8
+ Revision: 1621821
- Update to version 1.13.1
- Expose internal packages in the OSGi metadata

* Tue Aug 11 2020 neoclust <neoclust> 1.12.1-1.mga8
+ Revision: 1613338
- New version 1.12.1

* Fri Feb 14 2020 umeabot <umeabot> 1.11.3-2.mga8
+ Revision: 1520784
- Mageia 8 Mass Rebuild

* Mon Dec 10 2018 daviddavid <daviddavid> 1.11.3-1.mga7
+ Revision: 1339799
- new version: 1.11.3 (sync with fc29)

* Thu Sep 20 2018 umeabot <umeabot> 1.11.2-2.mga7
+ Revision: 1279141
- Mageia 7 Mass Rebuild

* Thu Apr 12 2018 kekepower <kekepower> 1.11.2-1.mga7
+ Revision: 1217847
- Fix BuildRequires
- Remove online tests
- Update to version 1.11.2
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Mar 01 2016 neoclust <neoclust> 1.8.3a-3.mga6
+ Revision: 981710
- First rebuild of the java stack
- sync package jsoup with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 daviddavid <daviddavid> 1.8.3a-2.mga6
+ Revision: 870882
- fix owner of maven-poms dir and java dir

* Sat Aug 29 2015 daviddavid <daviddavid> 1.8.3a-1.mga6
+ Revision: 870850
- new version: 1.8.3a (fix CVE-2015-6748) (mga#16663)
- update Source URL
- remove animal-sniffer-maven-plugin (as it is not available)
- use %%license macro

* Sun Jan 18 2015 daviddavid <daviddavid> 1.7.2-4.mga5
+ Revision: 811321
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 1.7.2-3.mga5
+ Revision: 746087
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 01 2014 dmorgan <dmorgan> 1.7.2-1.mga5
+ Revision: 630573
- New version

* Fri Oct 18 2013 umeabot <umeabot> 1.6.1-5.mga4
+ Revision: 506493
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.6.1-4.mga3
+ Revision: 355634
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jul 16 2012 dmorgan <dmorgan> 1.6.1-3.mga3
+ Revision: 271279
- Remove maven from requires
- imported package jsoup


* Fri Jul 22 2011 Jaromir Capik <jcapik@redhat.com> - 1.6.1-2
- Switching to sources from github

* Fri Jul 22 2011 Jaromir Capik <jcapik@redhat.com> - 1.6.1-1
- Initial package

